@@ -36,15 +36,14 @@ from mgetool.tool import parallelize, batch_parallelize
 from pymatgen.core import Structure
 
 from featurebox.featurizers.base_transform import DummyConverter, BaseFeature, Converter, ConverterCat
-from featurebox.featurizers.envir.environment import GEONNGet, env_method, env_names
-from featurebox.featurizers.envir.local_env import NNDict
+from featurebox.featurizers.envir.environment import GEONNGet, env_method
 from featurebox.utils.look_json import get_marked_class
 
 
 class _BaseStructureGraphGEO(BaseFeature):
 
     def __init__(self, collect=False, return_type="tensor", batch_calculate: bool = True,
-                 add_label=False,check=True,
+                 add_label=False, check=True,
                  **kwargs):
         """
 
@@ -68,7 +67,7 @@ class _BaseStructureGraphGEO(BaseFeature):
         self.collect = collect
         self.convert_funcs = [i for i in dir(self) if "_convert_" in i]
         self.add_label = add_label
-        self.check=check
+        self.check = check
 
     def __add__(self, other):
         raise TypeError("There is no add.")
@@ -153,7 +152,7 @@ class _BaseStructureGraphGEO(BaseFeature):
                 output[n] = np_data
         return output
 
-    def transform(self, structures: List[Structure], state_attributes=None, y=None,  **kwargs) -> List[
+    def transform(self, structures: List[Structure], state_attributes=None, y=None, **kwargs) -> List[
         Dict]:
         """
         New type of transform structure.
@@ -271,15 +270,21 @@ class _BaseStructureGraphGEO(BaseFeature):
                                       "such as ``_convert_edge_attr``.")
         result_old = [getattr(self, i)(structure, **kwargs) for i in convert_funcs]
         result = {}
-        [result.update(i) for i in result_old]
-
+        for dcti in result_old:
+            for k in dcti:
+                if k in result:
+                    result[k] = np.concatenate((result[k], dcti[k]),
+                                               axis=-1)  # please just for state-attr,edge_attr, and x
+                else:
+                    result[k] = dcti[k]
         result = {key: value for key, value in result.items() if key in self.graph_data_name}
         if self.check:
             for key, value in result.items():
                 if key != "y":
                     if not np.all(np.isreal(value)):
-                        raise ValueError("There is not real numerical data for {} of {}.  Not Acceptable: nan, infinite, complex.".format(
-                        structure.composition, key))
+                        raise ValueError(
+                            "There is not real numerical data for {} of {}.  Not Acceptable: nan, infinite, complex.".format(
+                                structure.composition, key))
 
         if self.return_type == "tensor":
             result = rs(result)
@@ -444,13 +449,15 @@ class StructureGraphGEO(BaseStructureGraphGEO):
                  bond_generator=None,
                  bond_converter: Converter = None,
                  cutoff: float = 5.0,
+                 pbc=True,
                  **kwargs):
         """
         Args:
             nn_strategy: (str) NearNeighbor strategy.
                 ["find_points_in_spheres", "find_xyz_in_spheres",
                 "BrunnerNN_reciprocal", "BrunnerNN_real", "BrunnerNN_relative",
-                "EconNN", "CrystalNN", "MinimumDistanceNNAll", "find_points_in_spheres","UserVoronoiNN"]
+                "EconNN", "CrystalNN", "MinimumDistanceNNAll", "find_points_in_spheres","UserVoronoiNN",
+                "ACSF","BehlerParrinello","EAD","EAMD","SOAP","SO3","SO4_Bispectrum","wACSF",]
             atom_converter: (BinaryMap) atom features converter.
                 See Also:
                 :class:`featurebox.test_featurizers.atom.mapper.AtomTableMap` , :class:`featurebox.test_featurizers.atom.mapper.AtomJsonMap` ,
@@ -463,7 +470,7 @@ class StructureGraphGEO(BaseStructureGraphGEO):
                 :class:`featurebox.test_featurizers.state.state_mapper.StructurePymatgenPropMap`
                 :mod:`featurebox.test_featurizers.state.statistics`
                 :mod:`featurebox.test_featurizers.state.union`
-            bond_generator: (GEONNGet, str)
+            bond_generator: (GEONNGet, )
                 bond features converter.
             cutoff: (float)
                 Whether to use depends on the ``nn_strategy``.
@@ -472,34 +479,24 @@ class StructureGraphGEO(BaseStructureGraphGEO):
         super().__init__(**kwargs)
         self.cutoff = cutoff
 
-        if bond_generator is None:  # default use GEONNDict
-            nn_strategy = get_marked_class(nn_strategy, NNDict)
-            # there use the universal parameter, custom it please
-            self.bond_generator = GEONNGet(nn_strategy,
-                                           numerical_tol=1e-8, pbc=None, cutoff=cutoff)
-        elif isinstance(bond_generator, str):  # new add "BaseDesGet"
-            # todo
-            self.nn_strategy = get_marked_class(nn_strategy, env_method[bond_generator])
-            # there use the universal parameter, custom it please
-            self.bond_generator = env_names[bond_generator](self.nn_strategy, self.cutoff,
-                                                            numerical_tol=1e-8, pbc=None, cutoff=self.cutoff)
-        else:  # defined BaseDesGet or BaseNNGet
-            # todo
+        nn_strategy = get_marked_class(nn_strategy, env_method)
+
+        if bond_generator is None or bond_generator == "GEONNDict":  # default use GEONNDict
+            self.bond_generator = GEONNGet(nn_strategy, numerical_tol=1e-8, pbc=pbc, cutoff=cutoff)
+        else:
+            bond_generator.nn_strategy = nn_strategy
             self.bond_generator = bond_generator
-            self.nn_strategy = self.bond_generator.nn_strategy
 
         self.bond_converter = bond_converter or self._get_dummy_converter()
 
-        self.graph_data_name = ["x", 'edge_index', "edge_weight", "edge_attr", 'y', 'pos', "state_attr", 'z']
+        self.graph_data_name = ["x", 'y', 'pos', "state_attr", 'z', 'edge_index', "edge_weight", "edge_attr", ]
 
-    def _convert_edges(self, structure:Structure, **kwargs):
+    def _convert_edges(self, structure: Structure, **kwargs):
         """get edge data."""
         _ = kwargs
 
         center_indices, edge_index, edge_attr, edge_weight, center_prop = self.bond_generator.convert(structure)
 
-        # remove dup
-
         index = edge_index[0] < edge_index[1]
 
         edge_index = edge_index[:, index]
@@ -542,9 +539,15 @@ class StructureGraphGEO(BaseStructureGraphGEO):
             edge_weight = edge_weight.ravel()
             if edge_weight.shape[0] == 0:
                 raise ValueError(
-                    "Bad data The {} is with no edge_index in cutoff. May lead to later wrong.".format(structure.composition), )
+                    "Bad data The {} is with no edge_index in cutoff. May lead to later wrong.".format(
+                        structure.composition), )
 
         if edge_attr.ndim <= 1:
             edge_attr = edge_attr.reshape(1, -1)
 
-        return {'edge_index': edge_index, "edge_weight": edge_weight, "edge_attr": edge_attr}
+        if center_prop is not None and np.all(np.isreal(center_prop)) and center_prop.size!=1:
+            center_prop = center_prop.astype(dtype=np.float32)
+
+            return {'edge_index': edge_index, "edge_weight": edge_weight, "edge_attr": edge_attr, "x": center_prop}
+        else:
+            return {'edge_index': edge_index, "edge_weight": edge_weight, "edge_attr": edge_attr}
