@@ -5,19 +5,106 @@ import numpy as np
 from ase import Atoms
 from pymatgen.analysis.local_env import NearNeighbors
 from pymatgen.core import Structure
-from pymatgen.io.ase import AseAtomsAdaptor
 
 from featurebox.featurizers.base_transform import BaseFeature
 from featurebox.featurizers.envir._get_radius_in_spheres import get_radius_in_spheres
 from featurebox.featurizers.envir._get_xyz_in_spheres import get_xyz_in_spheres
-from featurebox.featurizers.envir.desc_env import DesDict, universe_refine_des
-from featurebox.featurizers.envir.local_env import NNDict, get_strategy_in_spheres, universe_refine_nn, geo_refine_nn
+from featurebox.featurizers.envir.desc_env import DesDict, get_strategy2_in_spheres
+from featurebox.featurizers.envir.local_env import NNDict, get_strategy1_in_spheres
+from featurebox.utils.general import aaa
 from featurebox.utils.look_json import get_marked_class
 from featurebox.utils.predefined_typing import StructureOrMolecule, StructureOrMoleculeOrAtoms
 
 MODULE_DIR = Path(__file__).parent.parent.parent.absolute()
 
 
+def geo_refine_nn(center_indices, neighbor_indices, vectors, distances,
+                  center_prop=None, ele_numbers=None,
+                  fill_size=10,
+                  dis_sort=True,
+                  **kwargs):
+    """
+    Change each center atoms has fill_size neighbors.
+    More neighbors would be abandoned.
+    Insufficient neighbors would be duplicated.
+
+    Args:
+        center_indices: np.ndarray 1d
+        neighbor_indices: np.ndarray 1d
+        distances: np.ndarray 1d or np.ndarray 2d
+        vectors: np.ndarray 2d
+        center_prop:np.ndarray 2d
+        ele_numbers:np.ndarray 1d
+        fill_size: float, not use,
+        cutoff:
+        dis_sort:bool
+            sort neighbors with distance.
+
+    Returns:
+        (center_indices,center_indices,  neighbor_indices, images, distances)\n
+        center_indices: np.ndarray 1d(N,).\n
+        neighbor_indices: np.ndarray 2d(N,fill_size).\n
+        images: np.ndarray 2d(N,fill_size,l).\n
+        distance: np.ndarray 2d(N,fill_size,1).
+        center_prop: np.ndarray 1d(N,l_c).\n
+
+    where l, and l_c >= 1
+    """
+    _ = ele_numbers
+    _ = fill_size
+
+    if distances.ndim == 2:
+        neidx = np.lexsort((center_indices, distances[:, 0],))
+    else:
+        neidx = np.lexsort((center_indices, distances,))
+
+    cen_nei = center_indices[neidx]
+    nei_nei = neighbor_indices[neidx]
+    diss = distances[neidx]
+    if vectors is not None:
+        vecs = vectors[neidx, :]
+    else:
+        vecs = vectors
+
+    neis = np.vstack((cen_nei, nei_nei))
+
+    cen = np.array(sorted(set((np.concatenate((center_indices, neighbor_indices), axis=0).tolist()))))
+
+    cen = np.array(cen).ravel()
+
+    if diss.ndim == 1:
+        diss = np.array(diss)[..., np.newaxis]
+    else:
+        diss = np.array(diss)
+
+    if center_prop is None:  # must assort by rank of atom in structure before
+        return cen, neis, vecs, diss, np.array(cen).reshape(-1, 1),
+    else:
+        if center_prop.ndim == 1:
+            try:
+                center_prop = center_prop[cen]
+                center_prop = center_prop.reshape(-1, 1)
+            except ValueError:
+                raise UserWarning("center_prop is less than center atom number. Try to add cutoff.")
+        elif center_prop.ndim == 2 and center_prop.shape[0] == cen.shape[0]:
+            center_prop = center_prop[cen]
+        else:
+            center_prop = np.array(None)
+        return cen, neis, vecs, diss, center_prop
+
+
+#####################################################################################################################
+
+after_treatment_func_map = {"geo_refine_nn": geo_refine_nn, }
+# local env method
+env_method = {}
+env_method.update(NNDict)
+env_method.update(DesDict)
+
+
+#####################################################################################################################
+
+
 class _BaseEnvGet(BaseFeature):
     """
     Get properties from Pymatgen.Structure.
@@ -43,7 +130,7 @@ class _BaseEnvGet(BaseFeature):
                          batch_calculate=batch_calculate,
                          batch_size=batch_size)
         self.adaptor_dict = {}  # Dynamic assignment
-        self.adaptor = AseAtomsAdaptor()
+        self.adaptor = aaa
         self.pbc = True
         self.cutoff = 5.0
 
@@ -67,173 +154,8 @@ class _BaseEnvGet(BaseFeature):
             [atoms.__setattr__(k, v) for k, v in prop_dict.items()]
         return atoms
 
-    @staticmethod
-    def get_radius_in_spheres(
-            structure: StructureOrMolecule, cutoff: float = 5.0,
-            numerical_tol: float = 1e-8, pbc=True,
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
-        """
-        Get graph representations from structure within cutoff.
 
-        Args:
-            structure (pymatgen Structure or molecule)
-            cutoff (float): cutoff radius
-            numerical_tol (float): numerical tolerance
-            pbc (bool):True
-
-        Returns:
-            center_indices, neighbor_indices, images, distances
-        """
-        return get_radius_in_spheres(structure, cutoff=cutoff, numerical_tol=numerical_tol, pbc=pbc)
-
-    @staticmethod
-    def get_xyz_in_spheres(
-            structure: StructureOrMolecule, cutoff: float = 5.0,
-            numerical_tol: float = 1e-8, pbc=True,
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
-        """
-        Get graph representations from structure within cutoff.
-
-        Args:
-            structure (pymatgen Structure or molecule)
-            cutoff (float): cutoff radius
-            numerical_tol (float): numerical tolerance
-            pbc (bool):True
-        Returns:
-            center_indices, neighbor_indices, images, distances
-        """
-        return get_xyz_in_spheres(structure, cutoff=cutoff, numerical_tol=numerical_tol, pbc=pbc)
-
-
-class BaseDesGet(_BaseEnvGet):
-    """
-    Get properties from Pymatgen.Structure.
-    Where the nn_strategy is from ``pyXtal_FF``.
-    And each structure is convert to data as following :
-
-    ``center_indices``:np.ndarray of shape(n,)
-        center indexes.
-    ``neighbor_indices``:np.ndarray of shape(n,fill_size)
-        neighbor_indexes for each center_index.
-        `fill_size` is the parameter of `refine` function.
-    ``images``:np.ndarray of shape(n,lb>=3)
-        offset vector in 3 orientations or more bond properties.
-    ``distances``:np.ndarray of shape(n,fill_size)
-        distance of neighbor_indexes for each center_index.
-    ``center_properties``:np.ndarray of shape(n,l_c)
-        center properties.
-    """
-
-    def __init__(self, nn_strategy="SOAP", refine: str = None,
-                 refined_strategy_param: Dict = None,
-                 numerical_tol=1e-8, pbc: List[int] = None, cutoff=None, cut_off_name=None, check_align=True):
-        """
-
-        Parameters
-        ----------
-        nn_strategy:
-            pyXtelff descriptors, which has calculate method.
-            See Also:
-            :mod:`featurebox.test_featurizers.descriptors`,
-            :class:`featurebox.test_featurizers.descriptors.SOAP.SOAP`,
-        refine:str
-            sort method for neighbors of each atom.
-            all the refine_method should return 5 result.
-            See Also:
-            :func:`universe_refine_des`
-        refined_strategy_param:dict
-            parameters for refine
-        numerical_tol:float
-            numerical_tol
-        pbc:list
-            periodicity in 3 direction
-            3-length list,each one is 1 or 0. such as [0,0,0],The 1 mean in this direction is with periodicity.
-        cutoff:float
-
-        """
-
-        super().__init__(n_jobs=1, on_errors='raise', return_type='any')
-        if nn_strategy is None:
-            nn_strategy = "SOAP"
-        self.nn_strategy = get_marked_class(nn_strategy, DesDict)
-        assert hasattr(self.nn_strategy, "calculate"), "The strategy must have calculate method"
-        if refine is None:
-            self.refine = universe_refine_des
-        else:
-            self.refine = after_treatment_func_map_des[refine]
-        self.refined_strategy_param = refined_strategy_param if isinstance(refined_strategy_param, dict) else {}
-
-        if cut_off_name:
-            if cutoff:
-                setattr(self.nn_strategy, cut_off_name, cutoff)
-            self.cut_off_name = cut_off_name
-
-        else:
-            if cutoff is not None:
-                if hasattr(nn_strategy, "cutoff"):
-                    self.nn_strategy.cutoff = cutoff
-                    self.cut_off_name = "cutoff"
-
-                if hasattr(nn_strategy, "Rc"):
-                    self.nn_strategy.Rc = cutoff
-                    self.cut_off_name = "Rc"
-
-                if hasattr(nn_strategy, "rcut"):
-                    self.nn_strategy.rcut = cutoff
-                    self.cut_off_name = "rcut"
-                else:
-                    raise TypeError("Can't find cut radius name")
-            else:
-                self.cut_off_name = cut_off_name
-
-        self.cutoff = cutoff
-        self.numerical_tol = numerical_tol
-        self.pbc = pbc
-        self.check_align = check_align
-
-    def convert(self, structure):
-        """
-
-        Args:
-            structure:Structure,pymatgen Structure
-
-        Returns:
-            center_indices,center_prop,neighbor_indices,images,distances
-        """
-
-        return self.get_strategy(structure)
-
-    def get_calculate_in_spheres(self, d):
-        if isinstance(d, Structure):
-            d = self.pymatgen_to_ase(d)
-
-        d = self.nn_strategy.calculate(d)
-        return d
-
-    def get_strategy(self, structure: StructureOrMoleculeOrAtoms
-                     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
-        """For get bond distance with different strategy, for different nn_stagy could be rewrite"""
-
-        try:
-            result_dict = self.get_calculate_in_spheres(structure)
-            # todo add to refine
-            # center_indices, neighbor_indices, images, distances = self._within_cutoff(structure, self.cutoff,
-            #                                                                           self.numerical_tol)
-            result = self.refine(result_dict)
-        except ValueError as e:
-            print(e)
-            print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
-                str(structure.composition), getattr(self.nn_strategy, self.cut_off_name),
-                getattr(self.nn_strategy, self.cut_off_name) + 2)
-            )
-            setattr(self.nn_strategy, self.cut_off_name, getattr(self.nn_strategy, self.cut_off_name) + 2)
-            result_dict = self.get_calculate_in_spheres(structure)
-            result = self.refine(result_dict)
-
-        return result
-
-
-class BaseNNGet(_BaseEnvGet):
+class GEONNGet(_BaseEnvGet):
     """
     Get properties from Pymatgen.Structure.
     Where the nn_strategy is from ``Pymatgen``.
@@ -252,17 +174,21 @@ class BaseNNGet(_BaseEnvGet):
         center properties.
     """
 
-    def __init__(self, nn_strategy: Union[NearNeighbors] = "UserVoronoiNN", refine: str = None,
+    def __init__(self, nn_strategy: Union[NearNeighbors, str] = "UserVoronoiNN", refine: str = "geo_refine_nn",
                  refined_strategy_param: Dict = None,
-                 numerical_tol=1e-8, pbc: List[int] = None, cutoff=5.0, check_align=True):
+                 numerical_tol=1e-8, pbc: Union[List[int], bool] = False, cutoff=5.0, check_align=True,
+                 cutoff_name="cutoff",
+                 n_jobs=1,
+                 on_errors='raise', return_type='any'):
         """
 
         Parameters
         ----------
-        nn_strategy: Union[NearNeighbors]
-            search method for local_env for each atom.
-            See Also:
-            :class:`featurebox.test_featurizers.envir.local_env.MinimumDistanceNNAll`,
+        nn_strategy: Union[NearNeighbors,str]
+            ["find_points_in_spheres", "find_xyz_in_spheres",
+            "BrunnerNN_reciprocal", "BrunnerNN_real", "BrunnerNN_relative",
+            "EconNN", "CrystalNN", "MinimumDistanceNNAll", "find_points_in_spheres","UserVoronoiNN",
+            "ACSF","BehlerParrinello","EAD","EAMD","SOAP","SO3","SO4_Bispectrum","wACSF",]
         refine:str
             sort method for neighbors of each atom.
             See Also:
@@ -272,20 +198,16 @@ class BaseNNGet(_BaseEnvGet):
         numerical_tol:float
             numerical_tol
         pbc:list
-            only for find "find_points_in_spheres".
             periodicity in 3 direction
             3-length list,each one is 1 or 0. such as [0,0,0],The 1 mean in this direction is with periodicity.
         cutoff:
-            if offered, the nn_strategy would be neglect and find neighbors using
-                ``find_points_in_spheres`` in pymatgen.
+            cutoff radius
         """
 
-        super().__init__(n_jobs=1, on_errors='raise', return_type='any')
-        self.nn_strategy = get_marked_class(nn_strategy, NNDict)
-        if refine is None:
-            self.refine = universe_refine_nn
-        else:
-            self.refine = after_treatment_func_map_nn[refine]
+        super().__init__(n_jobs=n_jobs, on_errors=on_errors, return_type=return_type)
+        self.nn_strategy = get_marked_class(nn_strategy, env_method)
+
+        self.refine = after_treatment_func_map[refine]
         self.refined_strategy_param = refined_strategy_param \
             if isinstance(refined_strategy_param, dict) else {}
         self.cutoff = cutoff
@@ -293,6 +215,43 @@ class BaseNNGet(_BaseEnvGet):
         self.pbc = pbc
         self.check_align = check_align
 
+        if isinstance(self.nn_strategy, str):
+            self.cutoff_name = cutoff_name
+
+        elif cutoff_name:
+            if cutoff:
+                setattr(self.nn_strategy, cutoff_name, cutoff)
+            self.cutoff_name = cutoff_name
+
+        else:
+            if cutoff is not None:
+                if hasattr(nn_strategy, "cutoff"):
+                    self.nn_strategy.cutoff = cutoff
+                    self.cutoff_name = "cutoff"
+
+                elif hasattr(nn_strategy, "Rc"):
+                    self.nn_strategy.Rc = cutoff
+                    self.cutoff_name = "Rc"
+
+                elif hasattr(nn_strategy, "rcut"):
+                    self.nn_strategy.rcut = cutoff
+                    self.cutoff_name = "rcut"
+                else:
+                    raise TypeError("Can't find cut radius name")
+            else:
+                self.cutoff_name = cutoff_name
+
+        if self.nn_strategy == "find_points_in_spheres":
+            self._convert = self.get_radius
+        elif self.nn_strategy == "find_xyz_in_spheres":
+            self._convert = self.get_xyz
+        elif self.nn_strategy.__class__.__name__ in NNDict:
+            self._convert = self.get_strategy1
+        elif self.nn_strategy.__class__.__name__ in DesDict:
+            self._convert = self.get_strategy2
+        else:
+            raise NameError("can't determining ", self.nn_strategy)
+
     def convert(self, structure: StructureOrMolecule) -> Tuple[
         np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
         """
@@ -303,21 +262,27 @@ class BaseNNGet(_BaseEnvGet):
         Returns:
             center_indices,center_prop,neighbor_indices,images,distances
         """
-        if self.nn_strategy == "find_points_in_spheres":
-            return self.get_radius(structure)
-        if self.nn_strategy == "find_xyz_in_spheres":
-            return self.get_xyz(structure)
-        else:
-            return self.get_strategy(structure)
+        return self._convert(structure, self.cutoff)
 
-    def get_xyz(self, structure: StructureOrMolecule
+    def _check(self, structure, result, cutoff) -> bool:
+        if len(result[0].tolist()) == len(structure.species) or not self.check_align:
+            return True
+        else:
+            print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
+                str(structure.composition), cutoff, cutoff + 2)
+            )
+            return False
+
+    def get_xyz(self, structure: StructureOrMolecule, cutoff
                 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
         """For quick get bond distance"""
+        if cutoff > 15:
+            raise ValueError("The cutoff is to large than cutoff.")
 
-        cutoff = self.cutoff
         numerical_tol = self.numerical_tol
 
-        result = self.get_xyz_in_spheres(structure, cutoff, numerical_tol)
+        result = get_xyz_in_spheres(structure, nn_strategy=None, cutoff=cutoff, numerical_tol=numerical_tol,
+                                    pbc=self.pbc)
         # Result: center_indices, neighbor_indices, images, distances, center_prop
         ele_numbers = np.array(structure.atomic_numbers)
         result = self.refine(*result, ele_numbers=ele_numbers, **self.refined_strategy_param, )
@@ -326,19 +291,21 @@ class BaseNNGet(_BaseEnvGet):
         if len(result[0].tolist()) == len(structure.species) or not self.check_align:
             return result
         else:
-            self.cutoff += 2
+
             print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
                 str(structure.composition), cutoff, cutoff + 2))
-            return self.get_xyz(structure)
+            return self.get_xyz(structure, cutoff + 2)
 
-    def get_radius(self, structure: StructureOrMolecule
+    def get_radius(self, structure: StructureOrMolecule, cutoff
                    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
         """For quick get bond distance"""
+        if cutoff > 15:
+            raise ValueError("The cutoff is to large than cutoff.")
 
-        cutoff = self.cutoff
         numerical_tol = self.numerical_tol
 
-        result = self.get_radius_in_spheres(structure, cutoff, numerical_tol)
+        result = get_radius_in_spheres(structure, nn_strategy=None, cutoff=cutoff, numerical_tol=numerical_tol,
+                                       pbc=self.pbc)
         # Result: center_indices, neighbor_indices, images, distances, center_prop
         ele_numbers = np.array(structure.atomic_numbers)
         result = self.refine(*result, ele_numbers=ele_numbers, **self.refined_strategy_param, )
@@ -349,92 +316,50 @@ class BaseNNGet(_BaseEnvGet):
         else:
             print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
                 str(structure.composition), cutoff, cutoff + 2))
-            self.cutoff += 2
-            return self.get_radius(structure)
+            return self.get_radius(structure, cutoff + 2)
 
-    def get_strategy(self, structure: StructureOrMolecule
-                     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+    def get_strategy1(self, structure: StructureOrMolecule, cutoff
+                      ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
         """For get bond distance with different strategy, for different nn_staagy could be rewrite."""
         # assert hasattr(self.nn_strategy, "cutoff")
-        cutoff = self.cutoff
+        if cutoff > 15:
+            raise ValueError("The cutoff is to large than cutoff.")
+
         numerical_tol = self.numerical_tol
 
-        result = get_strategy_in_spheres(structure, self.nn_strategy, cutoff, numerical_tol)
+        result = get_strategy1_in_spheres(structure, nn_strategy=self.nn_strategy, cutoff=cutoff,
+                                          numerical_tol=numerical_tol,
+                                          pbc=self.pbc)
 
         ele_numbers = np.array(structure.atomic_numbers)
         result = self.refine(*result, ele_numbers=ele_numbers, **self.refined_strategy_param)
 
-        if len(result[0].tolist()) == len(structure.species) or not self.check_align:
+        if self._check(structure, result, cutoff):
             return result
         else:
-            if hasattr(self.nn_strategy, "min_bond_distance"):
-                print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
-                    str(structure.composition), self.nn_strategy.min_bond_distance,
-                    self.nn_strategy.min_bond_distance + 0.1)
-                )
-                self.nn_strategy.min_bond_distance += 0.1
-            else:
-                print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
-                    str(structure.composition), self.nn_strategy.cutoff, self.nn_strategy.cutoff + 2)
-                )
-            self.nn_strategy.cutoff += 2
-            self.cutoff += 2
-            return self.get_strategy(structure)
+            return self.get_strategy1(structure, cutoff + 2)
 
+    def get_strategy2(self, structure: StructureOrMoleculeOrAtoms, cutoff
+                      ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+        """For get bond distance with different strategy, for different nn_staagy could be rewrite."""
 
-class GEONNGet(BaseNNGet):
+        if cutoff > 15:
+            raise ValueError("The cutoff is to large than cutoff.")
 
-    def __init__(self, nn_strategy: Union[NearNeighbors] = "find_points_in_spheres",
-                 refine="geo_refine_nn",
-                 refined_strategy_param: Dict = None,
-                 numerical_tol=1e-8, pbc: List[int] = None, cutoff=5.0, check_align=True):
-        """
+        numerical_tol = self.numerical_tol
 
-        Parameters
-        ----------
-        nn_strategy: Union[NearNeighbors]
-            search method for local_env for each atom.
-            See Also:
-            :class:`featurebox.test_featurizers.envir.local_env.MinimumDistanceNNAll`,
-        refine:str
-            sort method for neighbors of each atom.
-            See Also:
-            :func:`universe_refine_nn`
-        refined_strategy_param:dict
-            parameters for refine
-        numerical_tol:float
-            numerical_tol
-        pbc:list
-            only for find "find_points_in_spheres".
-            periodicity in 3 direction
-            3-length list,each one is 1 or 0. such as [0,0,0],The 1 mean in this direction is with periodicity.
-        cutoff:
-            if offered, the nn_strategy would be neglect and find neighbors using
-                ``find_points_in_spheres`` in pymatgen.
-        """
-        assert refine == "geo_refine_nn"
-        super().__init__(nn_strategy=nn_strategy,
-                         refine=refine,
-                         refined_strategy_param=refined_strategy_param,
-                         numerical_tol=numerical_tol, pbc=pbc,
-                         cutoff=cutoff,
-                         check_align=check_align,
-                         )
+        result = get_strategy2_in_spheres(structure, nn_strategy=self.nn_strategy, cutoff=cutoff,
+                                          numerical_tol=numerical_tol, pbc=self.pbc,
+                                          cutoff_name=self.cutoff_name)
 
+        ele_numbers = np.array(structure.atomic_numbers)
+        result = self.refine(*result, ele_numbers=ele_numbers, **self.refined_strategy_param)
 
-#####################################################################################################################
-after_treatment_func_map_des = {"universe_refine": universe_refine_des, "universe_refine_des": universe_refine_des}
+        if len(result[0]) == len(structure.species) or not self.check_align:
+            return result
+        else:
 
-after_treatment_func_map_nn = {"universe_refine": universe_refine_nn,
-                               "universe_refine_nn": universe_refine_nn,
-                               "geo_refine_nn": geo_refine_nn,
-                               }
-# class
-env_names = {"BaseNNGet": BaseNNGet, "BaseDesGet": BaseDesGet, "GEONNGet": GEONNGet}
-# local env method
-env_method = {"BaseNNGet": NNDict, "BaseDesGet": DesDict, "GEONNGet": NNDict}
-# after treatment
-env_after_treatment_func_map = {"BaseNNGet": after_treatment_func_map_nn,
-                                "BaseDesGet": after_treatment_func_map_des,
-                                "GEONNGet": after_treatment_func_map_nn, }
-#####################################################################################################################
+            print("For {}, There is no neighbor in cutoff {} A, try with cutoff {} A for this structure.".format(
+                str(structure.composition), cutoff, cutoff + 2)
+            )
+            return self.get_strategy2(structure, cutoff + 2)
